# Python Design Patterns
This small package contains Python implementations of design pattern which are frequently used in software engineering.
## Installation
This package can be installed via pip command:
```shell
$ pip install pydps
```
Or installed from source:
```shell
$ git clone https://github.com/hieupth/pydps.git
$ cd pydps
$ python setup.py install
```
## Maintainers
* [Hieu Pham](https://github.com/hieupth) (author)

*Please feel free to contact me if you have any question or interested in contributing to my open source projects or 
research*
## License
[MIT License](https://github.com/hieupth/pydps/blob/main/LICENSE) <br>
Copyright (c) 2021, [Hieu Pham](https://github.com/hieupth). All rights reserved